@@ -1,4 +1,10 @@
-## ----setup, include=FALSE-----------------------------------------------------
+## ----dynamic-chunk-options, include=FALSE-------------------------------------
+# In GitHub lint job, we don't have full JVM build
+# SparkR vignette fails to evaluate
+GITHUB_ACTIONS <- tolower(Sys.getenv("GITHUB_ACTIONS")) == "true"
+EVAL_CHUNK <- !GITHUB_ACTIONS
+
+## ----setup, include=FALSE, eval=EVAL_CHUNK------------------------------------
 library(knitr)
 opts_hooks$set(eval = function(options) {
   # override eval to FALSE only on windows
@@ -14,10 +20,10 @@ sparkSessionConfig <- list(spark.driver.extraJavaOptions = tmp_arg,
 old_java_opt <- Sys.getenv("_JAVA_OPTIONS")
 Sys.setenv("_JAVA_OPTIONS" = paste("-XX:-UsePerfData", old_java_opt, sep = " "))
 
-## ---- message=FALSE-----------------------------------------------------------
+## ---- message=FALSE, eval=EVAL_CHUNK------------------------------------------
 library(SparkR)
 
-## ---- include=FALSE-----------------------------------------------------------
+## ---- include=FALSE, eval=EVAL_CHUNK------------------------------------------
 # disable eval if java version not supported
 override_eval <- tryCatch(!is.numeric(SparkR:::checkJavaVersion()),
           error = function(e) { TRUE },
@@ -30,37 +36,37 @@ if (override_eval) {
   })
 }
 
-## ---- include=FALSE-----------------------------------------------------------
+## ---- include=FALSE, eval=EVAL_CHUNK------------------------------------------
 install.spark()
 sparkR.session(master = "local[1]", sparkConfig = sparkSessionConfig, enableHiveSupport = FALSE)
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  sparkR.session()
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
+sparkR.session()
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 cars <- cbind(model = rownames(mtcars), mtcars)
 carsDF <- createDataFrame(cars)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 head(carsDF)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 carsSubDF <- select(carsDF, "model", "mpg", "hp")
 carsSubDF <- filter(carsSubDF, carsSubDF$hp >= 200)
 head(carsSubDF)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 carsGPDF <- summarize(groupBy(carsDF, carsDF$gear), count = n(carsDF$gear))
 head(carsGPDF)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 carsGP <- collect(carsGPDF)
 class(carsGP)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 model <- spark.glm(carsDF, mpg ~ wt + cyl)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 summary(model)
 
 ## ---- eval=FALSE--------------------------------------------------------------
@@ -79,7 +85,7 @@ summary(model)
 #  spark_warehouse_path <- file.path(path.expand('~'), "spark-warehouse")
 #  sparkR.session(spark.sql.warehouse.dir = spark_warehouse_path)
 
-## ---- echo=FALSE, tidy = TRUE-------------------------------------------------
+## ---- echo=FALSE, tidy = TRUE, eval=EVAL_CHUNK--------------------------------
 paste("Spark", packageVersion("SparkR"))
 
 ## ---- eval=FALSE--------------------------------------------------------------
@@ -88,7 +94,7 @@ paste("Spark", packageVersion("SparkR"))
 ## ---- eval=FALSE--------------------------------------------------------------
 #  sparkR.session(master = "yarn")
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 df <- as.DataFrame(faithful)
 head(df)
 
@@ -98,20 +104,20 @@ head(df)
 ## ---- eval=FALSE--------------------------------------------------------------
 #  df <- read.df(csvPath, "csv", header = "true", inferSchema = "true", na.strings = "NA")
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 filePath <- paste0(sparkR.conf("spark.home"),
                          "/examples/src/main/resources/people.json")
 readLines(filePath, n = 2L)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 people <- read.df(filePath, "json")
 count(people)
 head(people)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 printSchema(people)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 people <- read.json(paste0(Sys.getenv("SPARK_HOME"),
                            c("/examples/src/main/resources/people.json",
                              "/examples/src/main/resources/people.json")))
@@ -132,46 +138,46 @@ count(people)
 #  # results is now a SparkDataFrame
 #  head(results)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 carsDF
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 printSchema(carsDF)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 head(select(carsDF, "mpg"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 head(filter(carsDF, carsDF$mpg < 20))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 numCyl <- summarize(groupBy(carsDF, carsDF$cyl), count = n(carsDF$cyl))
 head(numCyl)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 mean(cube(carsDF, "cyl", "gear", "am"), "mpg")
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 mean(rollup(carsDF, "cyl", "gear", "am"), "mpg")
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 carsDF_km <- carsDF
 carsDF_km$kmpg <- carsDF_km$mpg * 1.61
 head(select(carsDF_km, "model", "mpg", "kmpg"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 carsSubDF <- select(carsDF, "model", "mpg", "cyl")
 ws <- orderBy(windowPartitionBy("cyl"), "mpg")
 carsRank <- withColumn(carsSubDF, "rank", over(rank(), ws))
 head(carsRank, n = 20L)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 carsSubDF <- select(carsDF, "model", "mpg")
 schema <- "model STRING, mpg DOUBLE, kmpg DOUBLE"
 out <- dapply(carsSubDF, function(x) { x <- cbind(x, x$mpg * 1.61) }, schema)
 head(collect(out))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 out <- dapplyCollect(
          carsSubDF,
          function(x) {
@@ -179,7 +185,7 @@ out <- dapplyCollect(
          })
 head(out, 3)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 schema <- structType(structField("cyl", "double"), structField("max_mpg", "double"))
 result <- gapply(
     carsDF,
@@ -190,7 +196,7 @@ result <- gapply(
     schema)
 head(arrange(result, "max_mpg", decreasing = TRUE))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 result <- gapplyCollect(
     carsDF,
     "cyl",
@@ -201,7 +207,7 @@ result <- gapplyCollect(
     })
 head(result[order(result$max_mpg, decreasing = TRUE), ])
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 costs <- exp(seq(from = log(1), to = log(1000), length.out = 5))
 train <- function(cost) {
   stopifnot(requireNamespace("e1071", quietly = TRUE))
@@ -209,47 +215,47 @@ train <- function(cost) {
   summary(model)
 }
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 model.summaries <- spark.lapply(costs, train)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 class(model.summaries)
 
-## ---- include=FALSE-----------------------------------------------------------
+## ---- include=FALSE, eval=EVAL_CHUNK------------------------------------------
 ops <- options()
 options(max.print=40)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 print(model.summaries[[2]])
 
-## ---- include=FALSE-----------------------------------------------------------
+## ---- include=FALSE, eval=EVAL_CHUNK------------------------------------------
 options(ops)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 people <- read.df(paste0(sparkR.conf("spark.home"),
                          "/examples/src/main/resources/people.json"), "json")
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 createOrReplaceTempView(people, "people")
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 teenagers <- sql("SELECT name FROM people WHERE age >= 13 AND age <= 19")
 head(teenagers)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 splitDF_list <- randomSplit(carsDF, c(0.7, 0.3), seed = 0)
 carsDF_train <- splitDF_list[[1]]
 carsDF_test <- splitDF_list[[2]]
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 count(carsDF_train)
 head(carsDF_train)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 count(carsDF_test)
 head(carsDF_test)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 # load training data and create a DataFrame
 t <- as.data.frame(Titanic)
 training <- createDataFrame(t)
@@ -257,50 +263,50 @@ training <- createDataFrame(t)
 model <- spark.svmLinear(training,  Survived ~ ., regParam = 0.01, maxIter = 10)
 summary(model)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 prediction <- predict(model, training)
 head(select(prediction, "Class", "Sex", "Age", "Freq", "Survived", "prediction"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 t <- as.data.frame(Titanic)
 training <- createDataFrame(t)
 model <- spark.logit(training, Survived ~ ., regParam = 0.04741301)
 summary(model)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 fitted <- predict(model, training)
 head(select(fitted, "Class", "Sex", "Age", "Freq", "Survived", "prediction"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 t <- as.data.frame(Titanic)
 training <- createDataFrame(t)
 # Note in this case, Spark infers it is multinomial logistic regression, so family = "multinomial" is optional.
 model <- spark.logit(training, Class ~ ., regParam = 0.07815179)
 summary(model)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 t <- as.data.frame(Titanic)
 training <- createDataFrame(t)
 # fit a Multilayer Perceptron Classification Model
 model <- spark.mlp(training, Survived ~ Age + Sex, blockSize = 128, layers = c(2, 2), solver = "l-bfgs", maxIter = 100, tol = 0.5, stepSize = 1, seed = 1, initialWeights = c( 0, 0, 5, 5, 9, 9))
 
-## ---- include=FALSE-----------------------------------------------------------
+## ---- include=FALSE, eval=EVAL_CHUNK------------------------------------------
 ops <- options()
 options(max.print=5)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 # check the summary of the fitted model
 summary(model)
 
-## ---- include=FALSE-----------------------------------------------------------
+## ---- include=FALSE, eval=EVAL_CHUNK------------------------------------------
 options(ops)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 # make predictions use the fitted model
 predictions <- predict(model, training)
 head(select(predictions, predictions$prediction))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 titanic <- as.data.frame(Titanic)
 titanicDF <- createDataFrame(titanic[titanic$Freq > 0, -5])
 naiveBayesModel <- spark.naiveBayes(titanicDF, Survived ~ Class + Sex + Age)
@@ -308,7 +314,7 @@ summary(naiveBayesModel)
 naiveBayesPrediction <- predict(naiveBayesModel, titanicDF)
 head(select(naiveBayesPrediction, "Class", "Sex", "Age", "Survived", "prediction"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 t <- as.data.frame(Titanic)
 training <- createDataFrame(t)
 
@@ -318,7 +324,7 @@ summary(model)
 predictions <- predict(model, training)
 head(select(predictions, predictions$prediction))
 
-## ---- warning=FALSE-----------------------------------------------------------
+## ---- warning=FALSE, eval=EVAL_CHUNK------------------------------------------
 library(survival)
 ovarianDF <- createDataFrame(ovarian)
 aftModel <- spark.survreg(ovarianDF, Surv(futime, fustat) ~ ecog_ps + rx)
@@ -326,24 +332,24 @@ summary(aftModel)
 aftPredictions <- predict(aftModel, ovarianDF)
 head(aftPredictions)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 gaussianGLM <- spark.glm(carsDF, mpg ~ wt + hp)
 summary(gaussianGLM)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 gaussianFitted <- predict(gaussianGLM, carsDF)
 head(select(gaussianFitted, "model", "prediction", "mpg", "wt", "hp"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 tweedieGLM1 <- spark.glm(carsDF, mpg ~ wt + hp, family = "tweedie", var.power = 0.0)
 summary(tweedieGLM1)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 tweedieGLM2 <- spark.glm(carsDF, mpg ~ wt + hp, family = "tweedie",
                          var.power = 1.2, link.power = 0.0)
 summary(tweedieGLM2)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 y <- c(3.0, 6.0, 8.0, 5.0, 7.0)
 x <- c(1.0, 2.0, 3.5, 3.0, 4.0)
 w <- rep(1.0, 5)
@@ -353,24 +359,24 @@ isoregModel <- spark.isoreg(df, y ~ x, weightCol = "w")
 isoregFitted <- predict(isoregModel, df)
 head(select(isoregFitted, "x", "y", "prediction"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 newDF <- createDataFrame(data.frame(x = c(1.5, 3.2)))
 head(predict(isoregModel, newDF))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 model <- spark.lm(carsDF, mpg ~ wt + hp)
 
 summary(model)
 predictions <- predict(model, carsDF)
 head(select(predictions, predictions$prediction))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 model <- spark.fmRegressor(carsDF, mpg ~ wt + hp)
 summary(model)
 predictions <- predict(model, carsDF)
 head(select(predictions, predictions$prediction))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 t <- as.data.frame(Titanic)
 df <- createDataFrame(t)
 dtModel <- spark.decisionTree(df, Survived ~ ., type = "classification", maxDepth = 2)
@@ -378,7 +384,7 @@ summary(dtModel)
 predictions <- predict(dtModel, df)
 head(select(predictions, "Class", "Sex", "Age", "Freq", "Survived", "prediction"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 t <- as.data.frame(Titanic)
 df <- createDataFrame(t)
 gbtModel <- spark.gbt(df, Survived ~ ., type = "classification", maxDepth = 2, maxIter = 2)
@@ -386,7 +392,7 @@ summary(gbtModel)
 predictions <- predict(gbtModel, df)
 head(select(predictions, "Class", "Sex", "Age", "Freq", "Survived", "prediction"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 t <- as.data.frame(Titanic)
 df <- createDataFrame(t)
 rfModel <- spark.randomForest(df, Survived ~ ., type = "classification", maxDepth = 2, numTrees = 2)
@@ -394,7 +400,7 @@ summary(rfModel)
 predictions <- predict(rfModel, df)
 head(select(predictions, "Class", "Sex", "Age", "Freq", "Survived", "prediction"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 t <- as.data.frame(Titanic)
 training <- createDataFrame(t)
 model <- spark.bisectingKmeans(training, Class ~ Survived, k = 4)
@@ -402,7 +408,7 @@ summary(model)
 fitted <- predict(model, training)
 head(select(fitted, "Class", "prediction"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 X1 <- data.frame(V1 = rnorm(4), V2 = rnorm(4))
 X2 <- data.frame(V1 = rnorm(6, 3), V2 = rnorm(6, 4))
 data <- rbind(X1, X2)
@@ -412,13 +418,13 @@ summary(gmmModel)
 gmmFitted <- predict(gmmModel, df)
 head(select(gmmFitted, "V1", "V2", "prediction"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 kmeansModel <- spark.kmeans(carsDF, ~ mpg + hp + wt, k = 3)
 summary(kmeansModel)
 kmeansPredictions <- predict(kmeansModel, carsDF)
 head(select(kmeansPredictions, "model", "mpg", "hp", "wt", "prediction"), n = 20L)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 corpus <- data.frame(features = c(
   "1 2 6 0 2 3 1 1 0 0 3",
   "1 3 0 1 3 0 0 2 0 0 1",
@@ -436,11 +442,11 @@ corpusDF <- createDataFrame(corpus)
 model <- spark.lda(data = corpusDF, k = 5, optimizer = "em")
 summary(model)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 posterior <- spark.posterior(model, corpusDF)
 head(posterior)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 perplexity <- spark.perplexity(model, corpusDF)
 perplexity
 
@@ -461,14 +467,14 @@ perplexity
 #  predicted <- predict(model, df)
 #  head(predicted)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 df <- createDataFrame(list(list(0L, 1L, 1.0), list(0L, 2L, 1.0),
                            list(1L, 2L, 1.0), list(3L, 4L, 1.0),
                            list(4L, 0L, 0.1)),
                       schema = c("src", "dst", "weight"))
 head(spark.assignClusters(df, initMode = "degree", weightCol = "weight"))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 df <- selectExpr(createDataFrame(data.frame(rawItems = c(
   "T,R,U", "T,S", "V,R", "R,U,T,V", "R,S", "V,S,U", "U,R", "S,T", "V,R", "V,U,S",
   "T,V,U", "R,V", "T,S", "T,S", "S,T", "S,U", "T,R", "V,R", "S,V", "T,S,U"
@@ -476,16 +482,16 @@ df <- selectExpr(createDataFrame(data.frame(rawItems = c(
 
 fpm <- spark.fpGrowth(df, minSupport = 0.2, minConfidence = 0.5)
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 head(spark.freqItemsets(fpm))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 head(spark.associationRules(fpm))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 head(predict(fpm, df))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 df <- createDataFrame(list(list(list(list(1L, 2L), list(3L))),
                            list(list(list(1L), list(3L, 2L), list(1L, 2L))),
                            list(list(list(1L, 2L), list(5L))),
@@ -493,7 +499,7 @@ df <- createDataFrame(list(list(list(list(1L, 2L), list(3L))),
                       schema = c("sequence"))
 head(spark.findFrequentSequentialPatterns(df, minSupport = 0.5, maxPatternLength = 5L))
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 t <- as.data.frame(Titanic)
 df <- createDataFrame(t)
 freqStats <- head(select(df, mean(df$Freq), sd(df$Freq)))
@@ -504,7 +510,7 @@ test <- spark.kstest(df, "Freq", "norm", c(freqMean, freqStd))
 testSummary <- summary(test)
 testSummary
 
-## -----------------------------------------------------------------------------
+## ---- eval=EVAL_CHUNK---------------------------------------------------------
 t <- as.data.frame(Titanic)
 training <- createDataFrame(t)
 gaussianGLM <- spark.glm(training, Freq ~ Sex + Age, family = "gaussian")
@@ -565,9 +571,9 @@ unlink(modelPath)
 #  
 #  head(sql("select * from aggregates"))
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ---- echo=FALSE, eval=EVAL_CHUNK---------------------------------------------
 sparkR.session.stop()
 
-## ----cleanup, include=FALSE---------------------------------------------------
+## ----cleanup, include=FALSE, eval=EVAL_CHUNK----------------------------------
 SparkR:::uninstallDownloadedSpark()
 
